@@ -16,17 +16,25 @@ use crate::settings::toml::Target;
 use crate::terminal::interactive;
 use crate::terminal::message::{Message, StdOut};
 
-pub fn run(target: &Target, user: &GlobalUser, namespace_id: &str, filename: &Path) -> Result<()> {
-    match interactive::confirm(&format!(
-        "Are you sure you want to delete all keys in {}?",
-        filename.display()
-    )) {
-        Ok(true) => (),
-        Ok(false) => {
-            StdOut::info(&format!("Not deleting keys in {}", filename.display()));
-            return Ok(());
+pub fn run(
+    target: &Target,
+    user: &GlobalUser,
+    namespace_id: &str,
+    filename: &Path,
+    force: bool,
+) -> Result<()> {
+    if !force {
+        match interactive::confirm(&format!(
+            "Are you sure you want to delete all keys in {}?",
+            filename.display()
+        )) {
+            Ok(true) => (),
+            Ok(false) => {
+                StdOut::info(&format!("Not deleting keys in {}", filename.display()));
+                return Ok(());
+            }
+            Err(e) => anyhow::bail!(e),
         }
-        Err(e) => anyhow::bail!(e),
     }
 
     let keys: Vec<String> = match &metadata(filename) {
@@ -35,8 +43,12 @@ pub fn run(target: &Target, user: &GlobalUser, namespace_id: &str, filename: &Pa
             let keys_vec: Result<Vec<KeyValuePair>, serde_json::Error> =
                 serde_json::from_str(&data);
             match keys_vec {
-                Ok(keys_vec) => keys_vec.iter().map(|kv| { kv.key.to_owned() }).collect(),
-                Err(_) => anyhow::bail!("Failed to decode JSON. Please make sure to follow the format, [{\"key\": \"test_key\", \"value\": \"test_value\"}, ...]")
+                Ok(keys_vec) => keys_vec.iter().map(|kv| kv.key.to_owned()).collect(),
+                Err(_) => {
+                    // Hide '{' in this error message from the formatting machinery in bail macro
+                    let msg = "Failed to decode JSON. Please make sure to follow the format, [{\"key\": \"test_key\", \"value\": \"test_value\"}, ...]";
+                    anyhow::bail!(msg);
+                }
             }
         }
         Ok(_) => anyhow::bail!("{} should be a JSON file, but is not", filename.display()),
