@@ -6,7 +6,7 @@ use std::env;
 use std::fs;
 use std::fs::File;
 use std::io::prelude::*;
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 
 use super::output::WranglerjsOutput;
 
@@ -20,7 +20,7 @@ pub struct Bundle {
 // We call a {Bundle} the output of a {Bundler}; representing what {Webpack}
 // produces.
 impl Bundle {
-    pub fn new(package_dir: &PathBuf) -> Bundle {
+    pub fn new(package_dir: &Path) -> Bundle {
         Bundle {
             out: package_dir.join(BUNDLE_OUT),
         }
